==> JOB-3.1.2.tar.gz: JOB-3.1.2/ob/src/org/omg/CORBA/Object.java <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package org.omg.CORBA;

public interface Object
{
    boolean
    _is_a(String identifier);

    boolean
    _is_equivalent(org.omg.CORBA.Object that);

    boolean
    _non_existent();

    int
    _hash(int maximum);

    org.omg.CORBA.Object
    _duplicate();

    void
    _release();

    ImplementationDef
    _get_implementation();

    InterfaceDef
    _get_interface();

    Request
    _request(String s);

    Request
    _create_request(Context ctx, String operation,
		    NVList arg_list, NamedValue result);

    Request
    _create_request(Context ctx, String operation,
		    NVList arg_list, NamedValue result,
		    ExceptionList excepts, ContextList contexts);

    org.omg.CORBA.Policy
    _get_policy(int policy_type);

    org.omg.CORBA.Policy
    _get_effective_policy_override(int policy_type);

    org.omg.CORBA.Object
    _set_policy_overrides(org.omg.CORBA.Policy[] np,
			  org.omg.CORBA.SetOverrideType set_add)
	throws org.omg.CORBA.PolicyManagerPackage.InvalidPolicies;

    org.omg.CORBA.Policy[]
    _get_policy_overrides(int[] types);

    boolean
    _validate_policies(org.omg.CORBA.Policy[] inconsistent_policies);

    org.omg.CORBA.DomainManager[]
    _get_domain_managers();


    // For compatibility with Sun's JDK 1.2RC2 ORB

    org.omg.CORBA.Object
    _get_interface_def();
}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/ob/src/org/omg/CORBA/Object.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package org.omg.CORBA;

public interface Object
{
    boolean
    _is_a(String identifier);

    boolean
    _is_equivalent(org.omg.CORBA.Object that);

    boolean
    _non_existent();

    int
    _hash(int maximum);

    org.omg.CORBA.Object
    _duplicate();

    void
    _release();

    ImplementationDef
    _get_implementation();

    InterfaceDef
    _get_interface();

    Request
    _request(String s);

    Request
    _create_request(Context ctx, String operation,
		    NVList arg_list, NamedValue result);

    Request
    _create_request(Context ctx, String operation,
		    NVList arg_list, NamedValue result,
		    ExceptionList excepts, ContextList contexts);

    //
    // For compatibility with JDK 1.2
    //

    org.omg.CORBA.Object
    _get_interface_def();

    org.omg.CORBA.Policy
    _get_policy(int policy_type);

    org.omg.CORBA.Object
    _set_policy_override(org.omg.CORBA.Policy[] np,
                         org.omg.CORBA.SetOverrideType set_add);

    org.omg.CORBA.DomainManager[]
    _get_domain_managers();

    //
    // ORBacus specific
    //

    org.omg.CORBA.Object
    _set_policy_overrides(org.omg.CORBA.Policy[] np,
			  org.omg.CORBA.SetOverrideType set_add)
	throws org.omg.CORBA.PolicyManagerPackage.InvalidPolicies;

    org.omg.CORBA.Policy
    _get_effective_policy_override(int policy_type);

    org.omg.CORBA.Policy[]
    _get_policy_overrides(int[] types);

    boolean
    _validate_policies(org.omg.CORBA.Policy[] inconsistent_policies);
}
